@@ -17,10 +17,9 @@ pub fn atat_cmd(input: TokenStream) -> TokenStream {
     let CmdAttributes {
         cmd,
         resp,
-        error,
         timeout_ms,
+        attempts,
         abortable,
-        force_receive_state,
         value_sep,
         cmd_prefix,
         termination,
@@ -50,10 +49,10 @@ pub fn atat_cmd(input: TokenStream) -> TokenStream {
         None => quote! {},
     };
 
-    let force_receive = match force_receive_state {
-        Some(force_receive_state) => {
+    let attempts = match attempts {
+        Some(attempts) => {
             quote! {
-                const FORCE_RECEIVE_STATE: bool = #force_receive_state;
+                const ATTEMPTS: u8 = #attempts;
             }
         }
         None => quote! {},
@@ -64,8 +63,6 @@ pub fn atat_cmd(input: TokenStream) -> TokenStream {
         cmd_len += 1;
     }
 
-    let err = error.unwrap_or_else(|| syn::parse_str("atat::GenericError").unwrap());
-
     let (field_names, field_names_str): (Vec<_>, Vec<_>) = variants
         .iter()
         .map(|f| {
@@ -89,13 +86,12 @@ pub fn atat_cmd(input: TokenStream) -> TokenStream {
         #[automatically_derived]
         impl #impl_generics atat::AtatCmd<{ #ident_len + #cmd_len }> for #ident #ty_generics #where_clause {
             type Response = #resp;
-            type Error = #err;
 
             #timeout
 
             #abortable
 
-            #force_receive
+            #attempts
 
             #[inline]
             fn as_bytes(&self) -> atat::heapless::Vec<u8, { #ident_len + #cmd_len }> {
@@ -110,7 +106,7 @@ pub fn atat_cmd(input: TokenStream) -> TokenStream {
             }
 
             #[inline]
-            fn parse(&self, res: Result<&[u8], atat::InternalError>) -> core::result::Result<Self::Response, atat::Error<Self::Error>> {
+            fn parse(&self, res: Result<&[u8], atat::InternalError>) -> core::result::Result<Self::Response, atat::Error> {
                 match res {
                     Ok(resp) => atat::serde_at::from_slice::<#resp>(resp).map_err(|e| {
                         atat::Error::Parse
