@@ -19,10 +19,9 @@ pub struct ParseInput {
 pub struct CmdAttributes {
     pub cmd: String,
     pub resp: Path,
-    pub error: Option<Path>,
     pub timeout_ms: Option<u32>,
+    pub attempts: Option<u8>,
     pub abortable: Option<bool>,
-    pub force_receive_state: Option<bool>,
     pub value_sep: bool,
     pub cmd_prefix: String,
     pub termination: String,
@@ -254,10 +253,9 @@ impl Parse for CmdAttributes {
         let mut at_cmd = Self {
             cmd: cmd.value(),
             resp: response_ident,
-            error: None,
             timeout_ms: None,
+            attempts: None,
             abortable: None,
-            force_receive_state: None,
             value_sep: true,
             cmd_prefix: String::from("AT"),
             termination: String::from("\r\n"),
@@ -277,6 +275,18 @@ impl Parse for CmdAttributes {
                         ))
                     }
                 }
+            } else if optional.path.is_ident("attempts") {
+                match optional.lit {
+                    Lit::Int(v) => {
+                        at_cmd.attempts = Some(v.base10_parse().unwrap());
+                    }
+                    _ => {
+                        return Err(Error::new(
+                            call_site,
+                            "expected integer value for 'attempts'",
+                        ))
+                    }
+                }
             } else if optional.path.is_ident("abortable") {
                 match optional.lit {
                     Lit::Bool(v) => {
@@ -284,25 +294,6 @@ impl Parse for CmdAttributes {
                     }
                     _ => return Err(Error::new(call_site, "expected bool value for 'abortable'")),
                 }
-            } else if optional.path.is_ident("error") {
-                match optional.lit {
-                    Lit::Str(v) => {
-                        at_cmd.error = Some(v.parse().unwrap());
-                    }
-                    _ => return Err(Error::new(call_site, "expected bool value for 'abortable'")),
-                }
-            } else if optional.path.is_ident("force_receive_state") {
-                match optional.lit {
-                    Lit::Bool(v) => {
-                        at_cmd.force_receive_state = Some(v.value);
-                    }
-                    _ => {
-                        return Err(Error::new(
-                            call_site,
-                            "expected bool value for 'force_receive_state'",
-                        ))
-                    }
-                }
             } else if optional.path.is_ident("value_sep") {
                 match optional.lit {
                     Lit::Bool(v) => {
